| move_group | R Documentation |
move_group moves a group to a different position from
within a shiny server function.
The parameter from refers to the group-id you want to be moved.
Likewise to refers to the group-id of a group you want to
select as destination.
The difference between move_group2() and move_group() is that
move_group2() selects both
from and to by panel-id, whereas move_group() selects by group-id.
move_group(
dock_id,
from,
to,
position = NULL,
session = shiny::getDefaultReactiveDomain()
)
dock_id |
Dock unique id. When using modules the namespace is automatically added. |
from |
Group-id of a panel within the group that should be moved. |
to |
Group-id of a panel within the group you want as a destination. |
position |
Group position options: one of
|
session |
shiny session object. See https://dockview.dev/docs/api/dockview/panelApi/. |
This function is called for its side effect. It sends a message to JavaScript through the current websocket connection, leveraging the shiny session object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.