| remove_panel | R Documentation |
Remove Panel dynamically
remove_panel(dock_id, id, session = getDefaultReactiveDomain())
dock_id |
Dock unique id. When using modules the namespace is automatically added. |
id |
Id of the panel that ought to be removed. |
session |
shiny session object. See https://dockview.dev/docs/api/dockview/panelApi/. |
This function is called for its side effect. It sends a message to JavaScript through the current websocket connection, leveraging the shiny session object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.